.. webapi-error::
   :title: Token Generation Failed
   :instance: reviewboard.webapi.errors.TOKEN_GENERATION_FAILED

   The attempt to generate an API token had failed, due to too many
   conflicts in the database. This operation can be repeated.
